==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/tests/__init__.py <==
# coding: utf-8
# Need django-nose to run correctly
import os
import poplib
import email
from datetime import datetime 

from django.test import TestCase
from django.core import mail
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib import admin

from jmb.fax import models, codema, kpn

KEY_FILE = os.path.join(os.path.dirname(__file__), 'keys/privkey.pem')
CERT_FILE = os.path.join(os.path.dirname(__file__), 'keys/newcert.pem')

admin.autodiscover()

def diff_dict(dict1, dict2):
    
    diff_keys = set(dict1.keys()).symmetric_difference(set(dict2.keys()))
    if diff_keys:
        return "Keys don't match: %s" % diff_keys
    txt = []
    for key in dict1.keys():
        if not dict1[key] == dict2[key]:
             txt += ["Key '%s' differ: %s <> %s" % (key, dict1[key], dict2[key])]
    return "\n".join(txt)
                                                       

class Pop3TestsNet(TestCase):
    __test__= True
    def test_01_pop_no_ssl(self):
        """Connect to pop3 server senza ssl"""

        M = poplib.POP3('mail.thundersystems.it')
        M.user('mittente@thundersystems.it')
        try:
            M.pass_('isi')
            assert True
        except:
            assert False

    def test_02_pop_con_ssl(self):
        """Connect to pop3 server con ssl"""
        try:
            assert FAX_CODEMA_POP_USE_TLS == True
        except:
            return

        M = poplib.POP3_SSL(settings.FAX_CODEMA_HOST, 995, KEY_FILE, CERT_FILE)
        M.user(settings.FAX_CODEMA_USER)
        try:
            M.pass_(settings.FAX_CODEMA_PASSWORD)
            assert True
        except:
            assert False

class Pop3Test(TestCase):
    
    fixtures = ['fax.yaml', 'fax.json']

    def test_03_create_codema_msg_received(self):
        """Create a codema.CodemaMsg and parse a received notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/received'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'RECEIVED'
        assert codema_msg.info == {'sender_number': '027383429',
                                   'date_sent': datetime(2012, 3, 23, 12, 13, 37),
                                   'sender_number': '027383429',
                                   'sender': '027383429',
                                   'status_message': 'Fax ricevuto con id: 16056',
                                   'pages': 1, 'status' : 2,
                                   'recipient_number': '0226142904',
                                   }
        codema_msg.get_or_create()
        codema_msg.save_attached_file()
        recipient_list = codema_msg.notify(attach=True)
        assert recipient_list == ['uno.due@dev.it', 'cinque.sei@dev.it']
        assert len(mail.outbox) == 1
        assert mail.outbox[0].to == recipient_list
        assert len(mail.outbox[0].attachments) == 1
        
    def test_03a_received_partial(self):
        """Parse a receipt partially wrong"""

        msg_txt = open(os.path.join(os.path.dirname(__file__),'data/received_partial.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_txt.read(),
                                      subject="Ricevuto fax parziale da 0255012477 (n. registrazione 16952)")
        assert codema_msg.status == 'RECEIVED'
        assert codema_msg.info == {'sender_number': '0255012477',
                                   'date_sent': datetime(2012, 4, 24, 11, 31, 40),
                                   'pages': 2,
                                   'recipient_number': '0226142904', 'status' : 2,
                                   'status_message': 'Fax ricevuto con id: 16952',
                                   }
        fax = models.Fax(**codema_msg.info)
        fax.save()
        
    def test_04_create_codema_msg(self):
        """Create a codema.CodemaMsg and parse a failure sent notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/sent_failed'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info == {'recipient_number': '0200644640', 'status' : 5,
                                   'status_message': 'Fax non riuscito (Nessun circuito/canale disponibile) - 0200644640, fax di test <17237>'}

    def test_05_sent_ok(self):
        "fax sent correctly: parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/sent_ok.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
             subject="""Fax inviato - 0200644640, Ulteriore prova con id ID-FAX 1326 <18373>""")
        fax = models.Fax.objects.get(pk=1326)
        assert fax.status == 3 
        assert codema_msg.status == 'SENT'
        assert codema_msg.info == {
            'recipient_number': '0200644640', 'status' : 4, 'pages' : 2,
            'status_message': 'Fax inviato - 0200644640, Ulteriore prova con id <18373>',
            'date_sent': datetime(2012, 5, 3, 13, 3, 51),
            'id' : 1326,
            }
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1326
        assert fax.status == 4
        assert created is False

    def test_06_sent_ko(self):
        "fax failed : parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/fax_non_inviato.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
             subject='Fax non riuscito (Chiamata rifiutata) - 0270102031, APPUNTAMENTO PER VERIFICHE PERIODICHE ID-FAX 1399 <18496>')
        fax = models.Fax.objects.get(pk=1399)
        assert fax.status == 3
        assert codema_msg.status == 'FAILED_SENT'
        info = {
            'recipient_number': '0270102031', 'status' : 5,
            'status_message': 'Fax non riuscito (Chiamata rifiutata) - 0270102031, APPUNTAMENTO PER VERIFICHE PERIODICHE <18496>',
            'id' : 1399,
            }
        assert codema_msg.info == info, set(codema_msg.info.iteritems())-set(info.iteritems())
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1399
        assert fax.status == 5
        assert created is False

    def test_06b_sent_ko(self):
        "fax failed : parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/fax_non_inviato2.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
             subject='Fax non riuscito (Numero non allocato (non assegnato)) - 0222533903, INVIO FAX SOLLECITO ID-FAX 1425 <18559>')
        # fax = models.Fax.objects.get(pk=1399)
        # assert fax.status == 3
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info == {
            'recipient_number': '0222533903', 'status' : 5,
            'status_message': 'Fax non riuscito (Numero non allocato (non assegnato)) - 0222533903, INVIO FAX SOLLECITO <18559>',
            'id' : 1425,
            }
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1425
        assert fax.status == 5
        assert created is True

    def test_06c_formato_non_corretto(self):
        "Formato non corretto"
        msg_file = open(os.path.join(os.path.dirname(__file__),
                                     'data/failed_formato_non_corretto.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject = 'Errore FAX, formato file non corretto')
        assert codema_msg.status == 'FAILED_SENT'
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert created == True

    def test_06d_stazione_occupata(self):
        "Stazione occupata"
        msg_file = open(os.path.join(os.path.dirname(__file__),
                                     'data/sent_failed_busy.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject = 'Fax non riuscito (La stazione remota è OCCUPATA) - 037130152, ID-FAX 1486 LIBRETTO VP - VIA XXV APRILE OSPEDALETTO LODIGIANO <18743>')
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info['id'] == 1486
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert created == True

    def test_07_notifiers(self):
        "check notifiers"

        # send_at_received = True
        list_504 = models.FaxNumber.get_notifiers_in(number='0226142904')
        # send_at_received = False
        list_775 = models.FaxNumber.get_notifiers_in(number='0226142775')

        assert list_504 == ['uno.due@dev.it', 'cinque.sei@dev.it']
        assert list_775 == []

        self.assertRaises(AssertionError, models.FaxNumber.get_notifiers_in)

        # Mi mancano i permessi per cancellare. TODO
        # models.FaxNumber.objects.get(number='0226142775').delete()
        # # se è l'unico FaxNumber può stare anche senza number
        # nums = models.FaxNumber.get_notifiers_in()
        # assert nums == ['uno.due@dev.it', 'cinque.sei@dev.it']
        

    # def test_08_client(self):
    #     "prova client"
    #     #resp = self.client.get(reverse('admin:fax_list'))
    #     resp = self.client.get('/admin/fax')
    #     assert resp.status_code == 301

class KpnTest(TestCase):
    
    fixtures = ['fax.yaml', 'fax.json']

    def test_01(self):
        """Create a kpn.KpnMsg from xml"""

        info = {
            'date_sent': datetime(2013, 1, 18, 15, 17, 27),
            'id': '65438562',
            'pages': 1,
            'recipient_number': '',
            'sender': '0200644640',
            'sender_number': '0200644640',
            'seq_id': '1',
            'status': 2,
            'status_message': 'OK: Trasmissione completata con successo',
            'subject': 'Fax from me',
            }
        from_xml = kpn.parse_status_from_xml(open('data/status.xml').read())
        assert from_xml == info, diff_dict(from_xml, info)

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/tests/__init__.py <==
# coding: utf-8
# Need django-nose to run correctly
from __future__ import unicode_literals

import os
import poplib
import email
from datetime import datetime

from django.test import TestCase
from django.core import mail
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib import admin

from jmb.fax import models, codema, kpn

KEY_FILE = os.path.join(os.path.dirname(__file__), 'keys/privkey.pem')
CERT_FILE = os.path.join(os.path.dirname(__file__), 'keys/newcert.pem')

admin.autodiscover()

def diff_dict(dict1, dict2):

    diff_keys = set(dict1.keys()).symmetric_difference(set(dict2.keys()))
    if diff_keys:
        return "Keys don't match: %s" % diff_keys
    txt = []
    for key in dict1.keys():
        if not dict1[key] == dict2[key]:
            txt += ["Key '%s' differ: %s <> %s" % (key, dict1[key], dict2[key])]
    return "\n".join(txt)


class Pop3TestsNet(TestCase):
    __test__ = True

    def test_01_pop_no_ssl(self):
        """Connect to pop3 server senza ssl"""

        M = poplib.POP3('mail.thundersystems.it')
        M.user('mittente@thundersystems.it')
        try:
            M.pass_('isi')
            assert True
        except:
            assert False

    def test_02_pop_con_ssl(self):
        """Connect to pop3 server con ssl"""
        try:
            assert FAX_CODEMA_POP_USE_TLS == True
        except:
            return

        M = poplib.POP3_SSL(settings.FAX_CODEMA_HOST, 995, KEY_FILE, CERT_FILE)
        M.user(settings.FAX_CODEMA_USER)
        try:
            M.pass_(settings.FAX_CODEMA_PASSWORD)
            assert True
        except:
            assert False

class Pop3Test(TestCase):

    fixtures = ['fax.yaml', 'fax.json']

    def test_03_create_codema_msg_received(self):
        """Create a codema.CodemaMsg and parse a received notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__), 'data/received'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'RECEIVED'
        assert codema_msg.info == {'sender_number': '027383429',
                                   'date_sent': datetime(2012, 3, 23, 12, 13, 37),
                                   'sender_number': '027383429',
                                   'sender': '027383429',
                                   'status_message': 'Fax ricevuto con id: 16056',
                                   'pages': 1, 'status': 2,
                                   'recipient_number': '0226142904',
                                   }
        codema_msg.get_or_create()
        codema_msg.save_attached_file()
        recipient_list = codema_msg.notify(attach=True)
        assert recipient_list == ['uno.due@dev.it', 'cinque.sei@dev.it']
        assert len(mail.outbox) == 1
        assert mail.outbox[0].to == recipient_list
        assert len(mail.outbox[0].attachments) == 1

    def test_03a_received_partial(self):
        """Parse a receipt partially wrong"""

        msg_txt = open(os.path.join(os.path.dirname(__file__), 'data/received_partial.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_txt.read(),
                                      subject="Ricevuto fax parziale da 0255012477 (n. registrazione 16952)")
        assert codema_msg.status == 'RECEIVED'
        assert codema_msg.info == {'sender_number': '0255012477',
                                   'date_sent': datetime(2012, 4, 24, 11, 31, 40),
                                   'pages': 2,
                                   'recipient_number': '0226142904', 'status': 2,
                                   'status_message': 'Fax ricevuto con id: 16952',
                                   }
        fax = models.Fax(**codema_msg.info)
        fax.save()

    def test_04_create_codema_msg(self):
        """Create a codema.CodemaMsg and parse a failure sent notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__), 'data/sent_failed'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info == {'recipient_number': '0200644640', 'status': 5,
                                   'status_message': 'Fax non riuscito (Nessun circuito/canale disponibile) - 0200644640, fax di test <17237>'}

    def test_05_sent_ok(self):
        "fax sent correctly: parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__), 'data/sent_ok.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject="""Fax inviato - 0200644640, Ulteriore prova con id ID-FAX 1326 <18373>""")
        fax = models.Fax.objects.get(pk=1326)
        assert fax.status == 3
        assert codema_msg.status == 'SENT'
        assert codema_msg.info == {
            'recipient_number': '0200644640', 'status': 4, 'pages': 2,
            'status_message': 'Fax inviato - 0200644640, Ulteriore prova con id <18373>',
            'date_sent': datetime(2012, 5, 3, 13, 3, 51),
            'id': 1326,
        }
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1326
        assert fax.status == 4
        assert created is False

    def test_06_sent_ko(self):
        "fax failed : parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__), 'data/fax_non_inviato.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject='Fax non riuscito (Chiamata rifiutata) - 0270102031, APPUNTAMENTO PER VERIFICHE PERIODICHE ID-FAX 1399 <18496>')
        fax = models.Fax.objects.get(pk=1399)
        assert fax.status == 3
        assert codema_msg.status == 'FAILED_SENT'
        info = {
            'recipient_number': '0270102031', 'status': 5,
            'status_message': 'Fax non riuscito (Chiamata rifiutata) - 0270102031, APPUNTAMENTO PER VERIFICHE PERIODICHE <18496>',
            'id': 1399,
        }
        assert codema_msg.info == info, set(codema_msg.info.items())-set(info.items())
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1399
        assert fax.status == 5
        assert created is False

    def test_06b_sent_ko(self):
        "fax failed : parse body"

        msg_file = open(os.path.join(os.path.dirname(__file__), 'data/fax_non_inviato2.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject='Fax non riuscito (Numero non allocato (non assegnato)) - 0222533903, INVIO FAX SOLLECITO ID-FAX 1425 <18559>')
        # fax = models.Fax.objects.get(pk=1399)
        # assert fax.status == 3
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info == {
            'recipient_number': '0222533903', 'status': 5,
            'status_message': 'Fax non riuscito (Numero non allocato (non assegnato)) - 0222533903, INVIO FAX SOLLECITO <18559>',
            'id': 1425,
        }
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert fax.id == 1425
        assert fax.status == 5
        assert created is True

    def test_06c_formato_non_corretto(self):
        "Formato non corretto"
        msg_file = open(os.path.join(os.path.dirname(__file__),
                                     'data/failed_formato_non_corretto.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject='Errore FAX, formato file non corretto')
        assert codema_msg.status == 'FAILED_SENT'
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert created == True

    def test_06d_stazione_occupata(self):
        "Stazione occupata"
        msg_file = open(os.path.join(os.path.dirname(__file__),
                                     'data/sent_failed_busy.txt'))
        codema_msg = codema.CodemaMsg(notification=msg_file.read(),
                                      subject='Fax non riuscito (La stazione remota è OCCUPATA) - 037130152, ID-FAX 1486 LIBRETTO VP - VIA XXV APRILE OSPEDALETTO LODIGIANO <18743>')
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info['id'] == 1486
        fax, created = codema_msg.get_or_create(save=True, update=True)
        assert created == True

    def test_07_notifiers(self):
        "check notifiers"

        # send_at_received = True
        list_504 = models.FaxNumber.get_notifiers_in(number='0226142904')
        # send_at_received = False
        list_775 = models.FaxNumber.get_notifiers_in(number='0226142775')

        assert list_504 == ['uno.due@dev.it', 'cinque.sei@dev.it']
        assert list_775 == []

        self.assertRaises(AssertionError, models.FaxNumber.get_notifiers_in)

        # Mi mancano i permessi per cancellare. TODO
        # models.FaxNumber.objects.get(number='0226142775').delete()
        # # se è l'unico FaxNumber può stare anche senza number
        # nums = models.FaxNumber.get_notifiers_in()
        # assert nums == ['uno.due@dev.it', 'cinque.sei@dev.it']

    # def test_08_client(self):
    #     "prova client"
    #     #resp = self.client.get(reverse('admin:fax_list'))
    #     resp = self.client.get('/admin/fax')
    #     assert resp.status_code == 301

class KpnTest(TestCase):

    fixtures = ['fax.yaml', 'fax.json']

    def test_01(self):
        """Create a kpn.KpnMsg from xml"""

        info = {
            'date_sent': datetime(2013, 1, 18, 15, 17, 27),
            'id': '65438562',
            'pages': 1,
            'recipient_number': '',
            'sender': '0200644640',
            'sender_number': '0200644640',
            'seq_id': '1',
            'status': 2,
            'status_message': 'OK: Trasmissione completata con successo',
            'subject': 'Fax from me',
        }
        from_xml = kpn.parse_status_from_xml(open('data/status.xml').read())
        assert from_xml == info, diff_dict(from_xml, info)
